diff --git a/Core/.idea/vcs.xml b/Core/.idea/vcs.xml
index b2bdec2..fdf1fc8 100644
--- a/Core/.idea/vcs.xml
+++ b/Core/.idea/vcs.xml
@@ -2,5 +2,6 @@
+
\ No newline at end of file
diff --git a/Core/CMakeLists.txt b/Core/CMakeLists.txt
index 557c397..f7a1aa0 100644
--- a/Core/CMakeLists.txt
+++ b/Core/CMakeLists.txt
@@ -3,4 +3,4 @@ project(Core)
set(CMAKE_CXX_STANDARD 14)
-add_library(Core SHARED library.cpp library.h NetworkManager.cpp NetworkManager.h)
\ No newline at end of file
+add_library(Core SHARED NetworkManager.cpp NetworkManager.h)
\ No newline at end of file
diff --git a/Core/cmake-build-debug/CMakeCache.txt b/Core/cmake-build-debug/CMakeCache.txt
index 8bf066e..b3448c6 100644
--- a/Core/cmake-build-debug/CMakeCache.txt
+++ b/Core/cmake-build-debug/CMakeCache.txt
@@ -1,5 +1,5 @@
# This is the CMakeCache file.
-# For build in directory: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug
+# For build in directory: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug
# It was generated by CMake: /Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake
# You can edit this file to change values found and used by cmake.
# If you do not want to change any of the values, simply exit the editor.
@@ -213,10 +213,10 @@ CMAKE_STRIP:FILEPATH=/Applications/Xcode.app/Contents/Developer/Toolchains/Xcode
CMAKE_VERBOSE_MAKEFILE:BOOL=FALSE
//Value Computed by CMake
-Core_BINARY_DIR:STATIC=/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug
+Core_BINARY_DIR:STATIC=/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug
//Value Computed by CMake
-Core_SOURCE_DIR:STATIC=/Users/imacgws/Desktop/C++ library/Core
+Core_SOURCE_DIR:STATIC=/Users/imacgws/Desktop/NetworkManager/Core
//Path to a program.
ProcessorCount_cmd_sysctl:FILEPATH=/usr/sbin/sysctl
@@ -229,7 +229,7 @@ ProcessorCount_cmd_sysctl:FILEPATH=/usr/sbin/sysctl
//ADVANCED property for variable: CMAKE_AR
CMAKE_AR-ADVANCED:INTERNAL=1
//This is the directory where this CMakeCache.txt was created
-CMAKE_CACHEFILE_DIR:INTERNAL=/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug
+CMAKE_CACHEFILE_DIR:INTERNAL=/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug
//Major version of cmake used to create the current loaded cache
CMAKE_CACHE_MAJOR_VERSION:INTERNAL=3
//Minor version of cmake used to create the current loaded cache
@@ -300,7 +300,7 @@ CMAKE_GENERATOR_PLATFORM:INTERNAL=
CMAKE_GENERATOR_TOOLSET:INTERNAL=
//Source directory with the top level CMakeLists.txt file for this
// project
-CMAKE_HOME_DIRECTORY:INTERNAL=/Users/imacgws/Desktop/C++ library/Core
+CMAKE_HOME_DIRECTORY:INTERNAL=/Users/imacgws/Desktop/NetworkManager/Core
//ADVANCED property for variable: CMAKE_INSTALL_NAME_TOOL
CMAKE_INSTALL_NAME_TOOL-ADVANCED:INTERNAL=1
//ADVANCED property for variable: CMAKE_LINKER
diff --git a/Core/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake b/Core/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
index e909034..1ab2a3b 100644
--- a/Core/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
+++ b/Core/cmake-build-debug/CMakeFiles/CMakeDirectoryInformation.cmake
@@ -2,8 +2,8 @@
# Generated by "Unix Makefiles" Generator, CMake Version 3.15
# Relative path conversion top directories.
-set(CMAKE_RELATIVE_PATH_TOP_SOURCE "/Users/imacgws/Desktop/C++ library/Core")
-set(CMAKE_RELATIVE_PATH_TOP_BINARY "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug")
+set(CMAKE_RELATIVE_PATH_TOP_SOURCE "/Users/imacgws/Desktop/NetworkManager/Core")
+set(CMAKE_RELATIVE_PATH_TOP_BINARY "/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug")
# Force unix paths in dependencies.
set(CMAKE_FORCE_UNIX_PATHS 1)
diff --git a/Core/cmake-build-debug/CMakeFiles/CMakeOutput.log b/Core/cmake-build-debug/CMakeFiles/CMakeOutput.log
index e082ce0..3e51979 100644
--- a/Core/cmake-build-debug/CMakeFiles/CMakeOutput.log
+++ b/Core/cmake-build-debug/CMakeFiles/CMakeOutput.log
@@ -10,7 +10,7 @@ The output was:
Compilation of the C compiler identification source "CMakeCCompilerId.c" produced "a.out"
-The C compiler identification is AppleClang, found in "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/3.15.3/CompilerIdC/a.out"
+The C compiler identification is AppleClang, found in "/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/3.15.3/CompilerIdC/a.out"
Compiling the CXX compiler identification source file "CMakeCXXCompilerId.cpp" succeeded.
Compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++
@@ -23,32 +23,32 @@ The output was:
Compilation of the CXX compiler identification source "CMakeCXXCompilerId.cpp" produced "a.out"
-The CXX compiler identification is AppleClang, found in "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/3.15.3/CompilerIdCXX/a.out"
+The CXX compiler identification is AppleClang, found in "/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/3.15.3/CompilerIdCXX/a.out"
Determining if the C compiler works passed with the following output:
-Change Dir: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp
+Change Dir: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp
-Run Build Command(s):/usr/bin/make cmTC_0fbe8/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_0fbe8.dir/build.make CMakeFiles/cmTC_0fbe8.dir/build
-Building C object CMakeFiles/cmTC_0fbe8.dir/testCCompiler.c.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o CMakeFiles/cmTC_0fbe8.dir/testCCompiler.c.o -c "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp/testCCompiler.c"
-Linking C executable cmTC_0fbe8
-/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_0fbe8.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names CMakeFiles/cmTC_0fbe8.dir/testCCompiler.c.o -o cmTC_0fbe8
+Run Build Command(s):/usr/bin/make cmTC_c6483/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_c6483.dir/build.make CMakeFiles/cmTC_c6483.dir/build
+Building C object CMakeFiles/cmTC_c6483.dir/testCCompiler.c.o
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o CMakeFiles/cmTC_c6483.dir/testCCompiler.c.o -c /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp/testCCompiler.c
+Linking C executable cmTC_c6483
+/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_c6483.dir/link.txt --verbose=1
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names CMakeFiles/cmTC_c6483.dir/testCCompiler.c.o -o cmTC_c6483
Detecting C compiler ABI info compiled with the following output:
-Change Dir: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp
+Change Dir: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp
-Run Build Command(s):/usr/bin/make cmTC_cc4fd/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_cc4fd.dir/build.make CMakeFiles/cmTC_cc4fd.dir/build
-Building C object CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c
+Run Build Command(s):/usr/bin/make cmTC_3e03a/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_3e03a.dir/build.make CMakeFiles/cmTC_3e03a.dir/build
+Building C object CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c
Apple clang version 11.0.0 (clang-1100.0.33.17)
Target: x86_64-apple-darwin19.2.0
Thread model: posix
InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin
clang: warning: -Wl,-v: 'linker' input unused [-Wunused-command-line-argument]
- "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCCompilerABI.c -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdebug-compilation-dir /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -x c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c
+ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCCompilerABI.c -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdebug-compilation-dir /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -x c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c
clang -cc1 version 11.0.0 (clang-1100.0.33.17) default target x86_64-apple-darwin19.2.0
ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/local/include"
ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/Library/Frameworks"
@@ -59,14 +59,14 @@ ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platf
/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/include
/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/System/Library/Frameworks (framework directory)
End of search list.
-Linking C executable cmTC_cc4fd
-/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_cc4fd.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -o cmTC_cc4fd
+Linking C executable cmTC_3e03a
+/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_3e03a.dir/link.txt --verbose=1
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -o cmTC_3e03a
Apple clang version 11.0.0 (clang-1100.0.33.17)
Target: x86_64-apple-darwin19.2.0
Thread model: posix
InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin
- "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_cc4fd -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a
+ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_3e03a -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a
@(#)PROGRAM:ld PROJECT:ld64-530
BUILD 18:57:17 Dec 13 2019
configured to support archs: armv6 armv7 armv7s arm64 arm64e arm64_32 i386 x86_64 x86_64h armv6m armv7k armv7m armv7em
@@ -92,17 +92,17 @@ Parsed C implicit include dir info from above output: rv=done
Parsed C implicit link information from above output:
link line regex: [^( *|.*[/\])(ld|CMAKE_LINK_STARTFILE-NOTFOUND|([^/\]+-)?ld|collect2)[^/\]*( |$)]
- ignore line: [Change Dir: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp]
+ ignore line: [Change Dir: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp]
ignore line: []
- ignore line: [Run Build Command(s):/usr/bin/make cmTC_cc4fd/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_cc4fd.dir/build.make CMakeFiles/cmTC_cc4fd.dir/build]
- ignore line: [Building C object CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o]
- ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c]
+ ignore line: [Run Build Command(s):/usr/bin/make cmTC_3e03a/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_3e03a.dir/build.make CMakeFiles/cmTC_3e03a.dir/build]
+ ignore line: [Building C object CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o]
+ ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c]
ignore line: [Apple clang version 11.0.0 (clang-1100.0.33.17)]
ignore line: [Target: x86_64-apple-darwin19.2.0]
ignore line: [Thread model: posix]
ignore line: [InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin]
ignore line: [clang: warning: -Wl,-v: 'linker' input unused [-Wunused-command-line-argument]]
- ignore line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCCompilerABI.c -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdebug-compilation-dir /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -x c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c]
+ ignore line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCCompilerABI.c -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdebug-compilation-dir /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -x c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCCompilerABI.c]
ignore line: [clang -cc1 version 11.0.0 (clang-1100.0.33.17) default target x86_64-apple-darwin19.2.0]
ignore line: [ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/local/include"]
ignore line: [ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/Library/Frameworks"]
@@ -113,14 +113,14 @@ Parsed C implicit link information from above output:
ignore line: [ /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/include]
ignore line: [ /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/System/Library/Frameworks (framework directory)]
ignore line: [End of search list.]
- ignore line: [Linking C executable cmTC_cc4fd]
- ignore line: [/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_cc4fd.dir/link.txt --verbose=1]
- ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -o cmTC_cc4fd ]
+ ignore line: [Linking C executable cmTC_3e03a]
+ ignore line: [/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_3e03a.dir/link.txt --verbose=1]
+ ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -o cmTC_3e03a ]
ignore line: [Apple clang version 11.0.0 (clang-1100.0.33.17)]
ignore line: [Target: x86_64-apple-darwin19.2.0]
ignore line: [Thread model: posix]
ignore line: [InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin]
- link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_cc4fd -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a]
+ link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_3e03a -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a]
arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld] ==> ignore
arg [-demangle] ==> ignore
arg [-lto_library] ==> ignore, skip following value
@@ -133,11 +133,11 @@ Parsed C implicit link information from above output:
arg [-syslibroot] ==> ignore
arg [/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk] ==> ignore
arg [-o] ==> ignore
- arg [cmTC_cc4fd] ==> ignore
+ arg [cmTC_3e03a] ==> ignore
arg [-search_paths_first] ==> ignore
arg [-headerpad_max_install_names] ==> ignore
arg [-v] ==> ignore
- arg [CMakeFiles/cmTC_cc4fd.dir/CMakeCCompilerABI.c.o] ==> ignore
+ arg [CMakeFiles/cmTC_3e03a.dir/CMakeCCompilerABI.c.o] ==> ignore
arg [-lSystem] ==> lib [System]
arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a] ==> lib [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a]
Library search paths: [;/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/lib]
@@ -152,29 +152,29 @@ Parsed C implicit link information from above output:
Determining if the CXX compiler works passed with the following output:
-Change Dir: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp
+Change Dir: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp
-Run Build Command(s):/usr/bin/make cmTC_ed86e/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_ed86e.dir/build.make CMakeFiles/cmTC_ed86e.dir/build
-Building CXX object CMakeFiles/cmTC_ed86e.dir/testCXXCompiler.cxx.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o CMakeFiles/cmTC_ed86e.dir/testCXXCompiler.cxx.o -c "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp/testCXXCompiler.cxx"
-Linking CXX executable cmTC_ed86e
-/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_ed86e.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names CMakeFiles/cmTC_ed86e.dir/testCXXCompiler.cxx.o -o cmTC_ed86e
+Run Build Command(s):/usr/bin/make cmTC_a13fb/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_a13fb.dir/build.make CMakeFiles/cmTC_a13fb.dir/build
+Building CXX object CMakeFiles/cmTC_a13fb.dir/testCXXCompiler.cxx.o
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o CMakeFiles/cmTC_a13fb.dir/testCXXCompiler.cxx.o -c /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp/testCXXCompiler.cxx
+Linking CXX executable cmTC_a13fb
+/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_a13fb.dir/link.txt --verbose=1
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names CMakeFiles/cmTC_a13fb.dir/testCXXCompiler.cxx.o -o cmTC_a13fb
Detecting CXX compiler ABI info compiled with the following output:
-Change Dir: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp
+Change Dir: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp
-Run Build Command(s):/usr/bin/make cmTC_82a28/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_82a28.dir/build.make CMakeFiles/cmTC_82a28.dir/build
-Building CXX object CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp
+Run Build Command(s):/usr/bin/make cmTC_d0ea6/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_d0ea6.dir/build.make CMakeFiles/cmTC_d0ea6.dir/build
+Building CXX object CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp
Apple clang version 11.0.0 (clang-1100.0.33.17)
Target: x86_64-apple-darwin19.2.0
Thread model: posix
InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin
clang: warning: -Wl,-v: 'linker' input unused [-Wunused-command-line-argument]
- "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCXXCompilerABI.cpp -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -stdlib=libc++ -internal-isystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../include/c++/v1 -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdeprecated-macro -fdebug-compilation-dir /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fcxx-exceptions -fexceptions -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -x c++ /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp
+ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCXXCompilerABI.cpp -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -stdlib=libc++ -internal-isystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../include/c++/v1 -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdeprecated-macro -fdebug-compilation-dir /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fcxx-exceptions -fexceptions -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -x c++ /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp
clang -cc1 version 11.0.0 (clang-1100.0.33.17) default target x86_64-apple-darwin19.2.0
ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/include/c++/v1"
ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/local/include"
@@ -187,14 +187,14 @@ ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platf
/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/include
/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/System/Library/Frameworks (framework directory)
End of search list.
-Linking CXX executable cmTC_82a28
-/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_82a28.dir/link.txt --verbose=1
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -o cmTC_82a28
+Linking CXX executable cmTC_d0ea6
+/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_d0ea6.dir/link.txt --verbose=1
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -o cmTC_d0ea6
Apple clang version 11.0.0 (clang-1100.0.33.17)
Target: x86_64-apple-darwin19.2.0
Thread model: posix
InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin
- "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_82a28 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a
+ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_d0ea6 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a
@(#)PROGRAM:ld PROJECT:ld64-530
BUILD 18:57:17 Dec 13 2019
configured to support archs: armv6 armv7 armv7s arm64 arm64e arm64_32 i386 x86_64 x86_64h armv6m armv7k armv7m armv7em
@@ -222,17 +222,17 @@ Parsed CXX implicit include dir info from above output: rv=done
Parsed CXX implicit link information from above output:
link line regex: [^( *|.*[/\])(ld|CMAKE_LINK_STARTFILE-NOTFOUND|([^/\]+-)?ld|collect2)[^/\]*( |$)]
- ignore line: [Change Dir: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp]
+ ignore line: [Change Dir: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp]
ignore line: []
- ignore line: [Run Build Command(s):/usr/bin/make cmTC_82a28/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_82a28.dir/build.make CMakeFiles/cmTC_82a28.dir/build]
- ignore line: [Building CXX object CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o]
- ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp]
+ ignore line: [Run Build Command(s):/usr/bin/make cmTC_d0ea6/fast && /Applications/Xcode.app/Contents/Developer/usr/bin/make -f CMakeFiles/cmTC_d0ea6.dir/build.make CMakeFiles/cmTC_d0ea6.dir/build]
+ ignore line: [Building CXX object CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o]
+ ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -v -Wl,-v -o CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -c /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp]
ignore line: [Apple clang version 11.0.0 (clang-1100.0.33.17)]
ignore line: [Target: x86_64-apple-darwin19.2.0]
ignore line: [Thread model: posix]
ignore line: [InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin]
ignore line: [clang: warning: -Wl,-v: 'linker' input unused [-Wunused-command-line-argument]]
- ignore line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCXXCompilerABI.cpp -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -stdlib=libc++ -internal-isystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../include/c++/v1 -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdeprecated-macro -fdebug-compilation-dir /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fcxx-exceptions -fexceptions -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -x c++ /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp]
+ ignore line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" -cc1 -triple x86_64-apple-macosx10.15.0 -Wdeprecated-objc-isa-usage -Werror=deprecated-objc-isa-usage -emit-obj -mrelax-all -disable-free -disable-llvm-verifier -discard-value-names -main-file-name CMakeCXXCompilerABI.cpp -mrelocation-model pic -pic-level 2 -mthread-model posix -mdisable-fp-elim -fno-strict-return -masm-verbose -munwind-tables -target-sdk-version=10.15 -target-cpu penryn -dwarf-column-info -debugger-tuning=lldb -ggnu-pubnames -target-linker-version 530 -v -coverage-notes-file /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp/CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.gcno -resource-dir /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0 -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -stdlib=libc++ -internal-isystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/../include/c++/v1 -Wno-framework-include-private-from-public -Wno-atimport-in-framework-header -Wno-extra-semi-stmt -Wno-quoted-include-in-framework-header -fdeprecated-macro -fdebug-compilation-dir /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/CMakeTmp -ferror-limit 19 -fmessage-length 0 -stack-protector 1 -fstack-check -mdarwin-stkchk-strong-link -fblocks -fencode-extended-block-signature -fregister-global-dtors-with-atexit -fobjc-runtime=macosx-10.15.0 -fcxx-exceptions -fexceptions -fmax-type-align=16 -fdiagnostics-show-option -o CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -x c++ /Applications/CLion.app/Contents/bin/cmake/mac/share/cmake-3.15/Modules/CMakeCXXCompilerABI.cpp]
ignore line: [clang -cc1 version 11.0.0 (clang-1100.0.33.17) default target x86_64-apple-darwin19.2.0]
ignore line: [ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/include/c++/v1"]
ignore line: [ignoring nonexistent directory "/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/local/include"]
@@ -245,14 +245,14 @@ Parsed CXX implicit link information from above output:
ignore line: [ /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/usr/include]
ignore line: [ /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk/System/Library/Frameworks (framework directory)]
ignore line: [End of search list.]
- ignore line: [Linking CXX executable cmTC_82a28]
- ignore line: [/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_82a28.dir/link.txt --verbose=1]
- ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -o cmTC_82a28 ]
+ ignore line: [Linking CXX executable cmTC_d0ea6]
+ ignore line: [/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E cmake_link_script CMakeFiles/cmTC_d0ea6.dir/link.txt --verbose=1]
+ ignore line: [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -Wl,-search_paths_first -Wl,-headerpad_max_install_names -v -Wl,-v CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -o cmTC_d0ea6 ]
ignore line: [Apple clang version 11.0.0 (clang-1100.0.33.17)]
ignore line: [Target: x86_64-apple-darwin19.2.0]
ignore line: [Thread model: posix]
ignore line: [InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin]
- link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_82a28 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a]
+ link line: [ "/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld" -demangle -lto_library /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/libLTO.dylib -dynamic -arch x86_64 -macosx_version_min 10.15.0 -syslibroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -o cmTC_d0ea6 -search_paths_first -headerpad_max_install_names -v CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o -lc++ -lSystem /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a]
arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/ld] ==> ignore
arg [-demangle] ==> ignore
arg [-lto_library] ==> ignore, skip following value
@@ -265,11 +265,11 @@ Parsed CXX implicit link information from above output:
arg [-syslibroot] ==> ignore
arg [/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk] ==> ignore
arg [-o] ==> ignore
- arg [cmTC_82a28] ==> ignore
+ arg [cmTC_d0ea6] ==> ignore
arg [-search_paths_first] ==> ignore
arg [-headerpad_max_install_names] ==> ignore
arg [-v] ==> ignore
- arg [CMakeFiles/cmTC_82a28.dir/CMakeCXXCompilerABI.cpp.o] ==> ignore
+ arg [CMakeFiles/cmTC_d0ea6.dir/CMakeCXXCompilerABI.cpp.o] ==> ignore
arg [-lc++] ==> lib [c++]
arg [-lSystem] ==> lib [System]
arg [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a] ==> lib [/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/11.0.0/lib/darwin/libclang_rt.osx.a]
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/CXX.includecache b/Core/cmake-build-debug/CMakeFiles/Core.dir/CXX.includecache
index ada5c9c..8e54ca9 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/CXX.includecache
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/CXX.includecache
@@ -6,13 +6,3 @@
#IncludeRegexTransform:
-/Users/imacgws/Desktop/C++ library/Core/NetworkManager.cpp
-string
--
-NetworkManager.h
-/Users/imacgws/Desktop/C++ library/Core/NetworkManager.h
-
-/Users/imacgws/Desktop/C++ library/Core/NetworkManager.h
-string
--
-
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/DependInfo.cmake b/Core/cmake-build-debug/CMakeFiles/Core.dir/DependInfo.cmake
index ba2473a..6f0a0a8 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/DependInfo.cmake
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/DependInfo.cmake
@@ -4,8 +4,7 @@ set(CMAKE_DEPENDS_LANGUAGES
)
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
- "/Users/imacgws/Desktop/C++ library/Core/NetworkManager.cpp" "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/Core.dir/NetworkManager.cpp.o"
- "/Users/imacgws/Desktop/C++ library/Core/library.cpp" "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/Core.dir/library.cpp.o"
+ "/Users/imacgws/Desktop/NetworkManager/Core/NetworkManager.cpp" "/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/Core.dir/NetworkManager.cpp.o"
)
set(CMAKE_CXX_COMPILER_ID "AppleClang")
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/build.make b/Core/cmake-build-debug/CMakeFiles/Core.dir/build.make
index 65ed4d7..407d11a 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/build.make
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/build.make
@@ -43,10 +43,10 @@ RM = /Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E remove -f
EQUALS = =
# The top-level source directory on which CMake was run.
-CMAKE_SOURCE_DIR = "/Users/imacgws/Desktop/C++ library/Core"
+CMAKE_SOURCE_DIR = /Users/imacgws/Desktop/NetworkManager/Core
# The top-level build directory on which CMake was run.
-CMAKE_BINARY_DIR = "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug"
+CMAKE_BINARY_DIR = /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug
# Include any dependencies generated for this target.
include CMakeFiles/Core.dir/depend.make
@@ -57,45 +57,30 @@ include CMakeFiles/Core.dir/progress.make
# Include the compile flags for this target's objects.
include CMakeFiles/Core.dir/flags.make
-CMakeFiles/Core.dir/library.cpp.o: CMakeFiles/Core.dir/flags.make
-CMakeFiles/Core.dir/library.cpp.o: ../library.cpp
- @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --progress-dir="/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" --progress-num=$(CMAKE_PROGRESS_1) "Building CXX object CMakeFiles/Core.dir/library.cpp.o"
- /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -o CMakeFiles/Core.dir/library.cpp.o -c "/Users/imacgws/Desktop/C++ library/Core/library.cpp"
-
-CMakeFiles/Core.dir/library.cpp.i: cmake_force
- @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green "Preprocessing CXX source to CMakeFiles/Core.dir/library.cpp.i"
- /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -E "/Users/imacgws/Desktop/C++ library/Core/library.cpp" > CMakeFiles/Core.dir/library.cpp.i
-
-CMakeFiles/Core.dir/library.cpp.s: cmake_force
- @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green "Compiling CXX source to assembly CMakeFiles/Core.dir/library.cpp.s"
- /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -S "/Users/imacgws/Desktop/C++ library/Core/library.cpp" -o CMakeFiles/Core.dir/library.cpp.s
-
CMakeFiles/Core.dir/NetworkManager.cpp.o: CMakeFiles/Core.dir/flags.make
CMakeFiles/Core.dir/NetworkManager.cpp.o: ../NetworkManager.cpp
- @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --progress-dir="/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" --progress-num=$(CMAKE_PROGRESS_2) "Building CXX object CMakeFiles/Core.dir/NetworkManager.cpp.o"
- /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -o CMakeFiles/Core.dir/NetworkManager.cpp.o -c "/Users/imacgws/Desktop/C++ library/Core/NetworkManager.cpp"
+ @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --progress-dir=/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles --progress-num=$(CMAKE_PROGRESS_1) "Building CXX object CMakeFiles/Core.dir/NetworkManager.cpp.o"
+ /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -o CMakeFiles/Core.dir/NetworkManager.cpp.o -c /Users/imacgws/Desktop/NetworkManager/Core/NetworkManager.cpp
CMakeFiles/Core.dir/NetworkManager.cpp.i: cmake_force
@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green "Preprocessing CXX source to CMakeFiles/Core.dir/NetworkManager.cpp.i"
- /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -E "/Users/imacgws/Desktop/C++ library/Core/NetworkManager.cpp" > CMakeFiles/Core.dir/NetworkManager.cpp.i
+ /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -E /Users/imacgws/Desktop/NetworkManager/Core/NetworkManager.cpp > CMakeFiles/Core.dir/NetworkManager.cpp.i
CMakeFiles/Core.dir/NetworkManager.cpp.s: cmake_force
@$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green "Compiling CXX source to assembly CMakeFiles/Core.dir/NetworkManager.cpp.s"
- /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -S "/Users/imacgws/Desktop/C++ library/Core/NetworkManager.cpp" -o CMakeFiles/Core.dir/NetworkManager.cpp.s
+ /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ $(CXX_DEFINES) $(CXX_INCLUDES) $(CXX_FLAGS) -S /Users/imacgws/Desktop/NetworkManager/Core/NetworkManager.cpp -o CMakeFiles/Core.dir/NetworkManager.cpp.s
# Object files for target Core
Core_OBJECTS = \
-"CMakeFiles/Core.dir/library.cpp.o" \
"CMakeFiles/Core.dir/NetworkManager.cpp.o"
# External object files for target Core
Core_EXTERNAL_OBJECTS =
-libCore.dylib: CMakeFiles/Core.dir/library.cpp.o
libCore.dylib: CMakeFiles/Core.dir/NetworkManager.cpp.o
libCore.dylib: CMakeFiles/Core.dir/build.make
libCore.dylib: CMakeFiles/Core.dir/link.txt
- @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --bold --progress-dir="/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" --progress-num=$(CMAKE_PROGRESS_3) "Linking CXX shared library libCore.dylib"
+ @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --green --bold --progress-dir=/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles --progress-num=$(CMAKE_PROGRESS_2) "Linking CXX shared library libCore.dylib"
$(CMAKE_COMMAND) -E cmake_link_script CMakeFiles/Core.dir/link.txt --verbose=$(VERBOSE)
# Rule to build all files generated by this target.
@@ -108,6 +93,6 @@ CMakeFiles/Core.dir/clean:
.PHONY : CMakeFiles/Core.dir/clean
CMakeFiles/Core.dir/depend:
- cd "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug" && $(CMAKE_COMMAND) -E cmake_depends "Unix Makefiles" "/Users/imacgws/Desktop/C++ library/Core" "/Users/imacgws/Desktop/C++ library/Core" "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug" "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug" "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/Core.dir/DependInfo.cmake" --color=$(COLOR)
+ cd /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug && $(CMAKE_COMMAND) -E cmake_depends "Unix Makefiles" /Users/imacgws/Desktop/NetworkManager/Core /Users/imacgws/Desktop/NetworkManager/Core /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/Core.dir/DependInfo.cmake --color=$(COLOR)
.PHONY : CMakeFiles/Core.dir/depend
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/cmake_clean.cmake b/Core/cmake-build-debug/CMakeFiles/Core.dir/cmake_clean.cmake
index 503eba8..3a77395 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/cmake_clean.cmake
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/cmake_clean.cmake
@@ -1,6 +1,5 @@
file(REMOVE_RECURSE
"CMakeFiles/Core.dir/NetworkManager.cpp.o"
- "CMakeFiles/Core.dir/library.cpp.o"
"libCore.dylib"
"libCore.pdb"
)
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.internal b/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.internal
index e5569e3..1fa422e 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.internal
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.internal
@@ -2,8 +2,5 @@
# Generated by "Unix Makefiles" Generator, CMake Version 3.15
CMakeFiles/Core.dir/NetworkManager.cpp.o
- /Users/imacgws/Desktop/C++ library/Core/NetworkManager.cpp
- /Users/imacgws/Desktop/C++ library/Core/NetworkManager.h
-CMakeFiles/Core.dir/library.cpp.o
- /Users/imacgws/Desktop/C++ library/Core/library.cpp
- /Users/imacgws/Desktop/C++ library/Core/library.h
+ /Users/imacgws/Desktop/NetworkManager/Core/NetworkManager.cpp
+ /Users/imacgws/Desktop/NetworkManager/Core/NetworkManager.h
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.make b/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.make
index fd11284..c665b01 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.make
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/depend.make
@@ -4,6 +4,3 @@
CMakeFiles/Core.dir/NetworkManager.cpp.o: ../NetworkManager.cpp
CMakeFiles/Core.dir/NetworkManager.cpp.o: ../NetworkManager.h
-CMakeFiles/Core.dir/library.cpp.o: ../library.cpp
-CMakeFiles/Core.dir/library.cpp.o: ../library.h
-
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/link.txt b/Core/cmake-build-debug/CMakeFiles/Core.dir/link.txt
index 9effc17..c15d1b4 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/link.txt
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/link.txt
@@ -1 +1 @@
-/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -g -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -dynamiclib -Wl,-headerpad_max_install_names -o libCore.dylib -install_name @rpath/libCore.dylib CMakeFiles/Core.dir/library.cpp.o CMakeFiles/Core.dir/NetworkManager.cpp.o
+/Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -g -isysroot /Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.15.sdk -dynamiclib -Wl,-headerpad_max_install_names -o libCore.dylib -install_name @rpath/libCore.dylib CMakeFiles/Core.dir/NetworkManager.cpp.o
diff --git a/Core/cmake-build-debug/CMakeFiles/Core.dir/progress.make b/Core/cmake-build-debug/CMakeFiles/Core.dir/progress.make
index 6a9dc74..abadeb0 100644
--- a/Core/cmake-build-debug/CMakeFiles/Core.dir/progress.make
+++ b/Core/cmake-build-debug/CMakeFiles/Core.dir/progress.make
@@ -1,4 +1,3 @@
CMAKE_PROGRESS_1 = 1
CMAKE_PROGRESS_2 = 2
-CMAKE_PROGRESS_3 = 3
diff --git a/Core/cmake-build-debug/CMakeFiles/Makefile2 b/Core/cmake-build-debug/CMakeFiles/Makefile2
index 7d5087d..556e9bd 100644
--- a/Core/cmake-build-debug/CMakeFiles/Makefile2
+++ b/Core/cmake-build-debug/CMakeFiles/Makefile2
@@ -44,10 +44,10 @@ RM = /Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E remove -f
EQUALS = =
# The top-level source directory on which CMake was run.
-CMAKE_SOURCE_DIR = "/Users/imacgws/Desktop/C++ library/Core"
+CMAKE_SOURCE_DIR = /Users/imacgws/Desktop/NetworkManager/Core
# The top-level build directory on which CMake was run.
-CMAKE_BINARY_DIR = "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug"
+CMAKE_BINARY_DIR = /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug
#=============================================================================
# Directory level rules for the build root directory
@@ -74,14 +74,14 @@ preinstall:
CMakeFiles/Core.dir/all:
$(MAKE) -f CMakeFiles/Core.dir/build.make CMakeFiles/Core.dir/depend
$(MAKE) -f CMakeFiles/Core.dir/build.make CMakeFiles/Core.dir/build
- @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --progress-dir="/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" --progress-num=1,2,3 "Built target Core"
+ @$(CMAKE_COMMAND) -E cmake_echo_color --switch=$(COLOR) --progress-dir=/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles --progress-num=1,2 "Built target Core"
.PHONY : CMakeFiles/Core.dir/all
# Build rule for subdir invocation for target.
CMakeFiles/Core.dir/rule: cmake_check_build_system
- $(CMAKE_COMMAND) -E cmake_progress_start "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" 3
+ $(CMAKE_COMMAND) -E cmake_progress_start /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles 2
$(MAKE) -f CMakeFiles/Makefile2 CMakeFiles/Core.dir/all
- $(CMAKE_COMMAND) -E cmake_progress_start "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" 0
+ $(CMAKE_COMMAND) -E cmake_progress_start /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles 0
.PHONY : CMakeFiles/Core.dir/rule
# Convenience name for target.
diff --git a/Core/cmake-build-debug/CMakeFiles/Progress/3 b/Core/cmake-build-debug/CMakeFiles/Progress/3
deleted file mode 100644
index 7b4d68d..0000000
--- a/Core/cmake-build-debug/CMakeFiles/Progress/3
+++ /dev/null
@@ -1 +0,0 @@
-empty
\ No newline at end of file
diff --git a/Core/cmake-build-debug/CMakeFiles/Progress/count.txt b/Core/cmake-build-debug/CMakeFiles/Progress/count.txt
index 00750ed..0cfbf08 100644
--- a/Core/cmake-build-debug/CMakeFiles/Progress/count.txt
+++ b/Core/cmake-build-debug/CMakeFiles/Progress/count.txt
@@ -1 +1 @@
-3
+2
diff --git a/Core/cmake-build-debug/CMakeFiles/TargetDirectories.txt b/Core/cmake-build-debug/CMakeFiles/TargetDirectories.txt
index d281f07..d408ec7 100644
--- a/Core/cmake-build-debug/CMakeFiles/TargetDirectories.txt
+++ b/Core/cmake-build-debug/CMakeFiles/TargetDirectories.txt
@@ -1,3 +1,3 @@
-/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/rebuild_cache.dir
-/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/edit_cache.dir
-/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/Core.dir
+/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/rebuild_cache.dir
+/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/edit_cache.dir
+/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/Core.dir
diff --git a/Core/cmake-build-debug/CMakeFiles/clion-log.txt b/Core/cmake-build-debug/CMakeFiles/clion-log.txt
index 5f848ca..8fcaded 100644
--- a/Core/cmake-build-debug/CMakeFiles/clion-log.txt
+++ b/Core/cmake-build-debug/CMakeFiles/clion-log.txt
@@ -1,4 +1,18 @@
-/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -DCMAKE_BUILD_TYPE=Debug -G "CodeBlocks - Unix Makefiles" "/Users/imacgws/Desktop/C++ library/Core"
+/Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -DCMAKE_BUILD_TYPE=Debug -G "CodeBlocks - Unix Makefiles" /Users/imacgws/Desktop/NetworkManager/Core
+-- The C compiler identification is AppleClang 11.0.0.11000033
+-- The CXX compiler identification is AppleClang 11.0.0.11000033
+-- Check for working C compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc
+-- Check for working C compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/cc -- works
+-- Detecting C compiler ABI info
+-- Detecting C compiler ABI info - done
+-- Detecting C compile features
+-- Detecting C compile features - done
+-- Check for working CXX compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++
+-- Check for working CXX compiler: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/c++ -- works
+-- Detecting CXX compiler ABI info
+-- Detecting CXX compiler ABI info - done
+-- Detecting CXX compile features
+-- Detecting CXX compile features - done
-- Configuring done
-- Generating done
--- Build files have been written to: /Users/imacgws/Desktop/C++ library/Core/cmake-build-debug
+-- Build files have been written to: /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug
diff --git a/Core/cmake-build-debug/CMakeFiles/progress.marks b/Core/cmake-build-debug/CMakeFiles/progress.marks
index 00750ed..0cfbf08 100644
--- a/Core/cmake-build-debug/CMakeFiles/progress.marks
+++ b/Core/cmake-build-debug/CMakeFiles/progress.marks
@@ -1 +1 @@
-3
+2
diff --git a/Core/cmake-build-debug/Core.cbp b/Core/cmake-build-debug/Core.cbp
index ce7ea41..3131716 100644
--- a/Core/cmake-build-debug/Core.cbp
+++ b/Core/cmake-build-debug/Core.cbp
@@ -8,38 +8,38 @@
-
+
-
-
-
-
+
+
+
+
-
+
-
-
-
-
+
+
+
+
-
+
-
-
-
-
+
+
+
+
-
-
+
+
@@ -52,15 +52,15 @@
-
-
-
-
+
+
+
+
-
-
+
+
@@ -73,26 +73,20 @@
-
-
-
-
+
+
+
+
-
+
-
+
-
-
-
-
-
-
-
+
diff --git a/Core/cmake-build-debug/Makefile b/Core/cmake-build-debug/Makefile
index 11fcc03..b0d0eaf 100644
--- a/Core/cmake-build-debug/Makefile
+++ b/Core/cmake-build-debug/Makefile
@@ -48,10 +48,10 @@ RM = /Applications/CLion.app/Contents/bin/cmake/mac/bin/cmake -E remove -f
EQUALS = =
# The top-level source directory on which CMake was run.
-CMAKE_SOURCE_DIR = "/Users/imacgws/Desktop/C++ library/Core"
+CMAKE_SOURCE_DIR = /Users/imacgws/Desktop/NetworkManager/Core
# The top-level build directory on which CMake was run.
-CMAKE_BINARY_DIR = "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug"
+CMAKE_BINARY_DIR = /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug
#=============================================================================
# Targets provided globally by CMake.
@@ -80,9 +80,9 @@ edit_cache/fast: edit_cache
# The main all target
all: cmake_check_build_system
- $(CMAKE_COMMAND) -E cmake_progress_start "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles/progress.marks"
+ $(CMAKE_COMMAND) -E cmake_progress_start /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles/progress.marks
$(MAKE) -f CMakeFiles/Makefile2 all
- $(CMAKE_COMMAND) -E cmake_progress_start "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/CMakeFiles" 0
+ $(CMAKE_COMMAND) -E cmake_progress_start /Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/CMakeFiles 0
.PHONY : all
# The main clean target
@@ -150,33 +150,6 @@ NetworkManager.cpp.s:
$(MAKE) -f CMakeFiles/Core.dir/build.make CMakeFiles/Core.dir/NetworkManager.cpp.s
.PHONY : NetworkManager.cpp.s
-library.o: library.cpp.o
-
-.PHONY : library.o
-
-# target to build an object file
-library.cpp.o:
- $(MAKE) -f CMakeFiles/Core.dir/build.make CMakeFiles/Core.dir/library.cpp.o
-.PHONY : library.cpp.o
-
-library.i: library.cpp.i
-
-.PHONY : library.i
-
-# target to preprocess a source file
-library.cpp.i:
- $(MAKE) -f CMakeFiles/Core.dir/build.make CMakeFiles/Core.dir/library.cpp.i
-.PHONY : library.cpp.i
-
-library.s: library.cpp.s
-
-.PHONY : library.s
-
-# target to generate assembly for a file
-library.cpp.s:
- $(MAKE) -f CMakeFiles/Core.dir/build.make CMakeFiles/Core.dir/library.cpp.s
-.PHONY : library.cpp.s
-
# Help Target
help:
@echo "The following are some of the valid targets for this Makefile:"
@@ -189,9 +162,6 @@ help:
@echo "... NetworkManager.o"
@echo "... NetworkManager.i"
@echo "... NetworkManager.s"
- @echo "... library.o"
- @echo "... library.i"
- @echo "... library.s"
.PHONY : help
diff --git a/Core/library.cpp b/Core/library.cpp
deleted file mode 100644
index 4b4c12a..0000000
--- a/Core/library.cpp
+++ /dev/null
@@ -1,36 +0,0 @@
-#include "library.h"
-
-#include
-using namespace std;
-
-class Junior {
- string name;
- int grade;
- // stage in year
- int stage;
- string sphere;
- friend string hello(Junior a);
-public:
- Junior() {
- this->name = "Ismoil";
- this->stage = 1;
- this->grade = 4;
- this->sphere = "iOS Developer";
- }
-
- Junior(string name, int grade, int stage, string sphere) {
- this->name = name;
- this->stage = stage;
- this->grade = grade;
- this->sphere = sphere;
- }
-
-};
-
-string hello(Junior a) {
- return "Hello " + a.name;
-}
-void hello() {
- Junior ismoil = Junior();
- cout << "Hello, World!" << hello(ismoil) << endl;
-}
\ No newline at end of file
diff --git a/Core/library.h b/Core/library.h
deleted file mode 100644
index 5a93322..0000000
--- a/Core/library.h
+++ /dev/null
@@ -1,6 +0,0 @@
-#ifndef CORE_LIBRARY_H
-#define CORE_LIBRARY_H
-
-void hello();
-
-#endif //CORE_LIBRARY_H
diff --git a/Core/cmake-build-debug/cmake_install.cmake b/Core/cmake-build-debug/cmake_install.cmake
index 894f05a..12f3a37 100644
--- a/Core/cmake-build-debug/cmake_install.cmake
+++ b/Core/cmake-build-debug/cmake_install.cmake
@@ -1,4 +1,4 @@
# Install script for directory: /Users/imacgws/Desktop/C++ library/Core
# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)
@@ -40,5 +40,5 @@ endif()
string(REPLACE ";" "\n" CMAKE_INSTALL_MANIFEST_CONTENT
"${CMAKE_INSTALL_MANIFEST_FILES}")
-file(WRITE "/Users/imacgws/Desktop/C++ library/Core/cmake-build-debug/${CMAKE_INSTALL_MANIFEST}"
+file(WRITE "/Users/imacgws/Desktop/NetworkManager/Core/cmake-build-debug/${CMAKE_INSTALL_MANIFEST}"
"${CMAKE_INSTALL_MANIFEST_CONTENT}")
@@ -1,4 +1,4 @@
-# Install script for directory: /Users/imacgws/Desktop/C++ library/Core
+# Install script for directory: /Users/imacgws/Desktop/NetworkManager/Core
# Set the install prefix
if(NOT DEFINED CMAKE_INSTALL_PREFIX)